// -*-c++-*-
//===========================================================
//=     University of Illinois at Urbana/Champaign          =
//=     Department of Computer Science                      =
//=     Dr. Dan Roth - Cognitive Computation Group          =
//=                                                         =
//=  Project: Snow                                          =
//=                                                         =
//=   Module: Example.h                                     =
//=  Version: 2.1                                           =
//=  Authors: Jeff Rosen and Andrew Carlson                 =
//=     Date: xx/xx/99                                      = 
//=                                                         =
//===========================================================

#ifndef __EXAMPLE_H__
#define __EXAMPLE_H__

#include "SnowTypes.h"
#include <string>
#include <iostream>
#include <fstream>
#include <map>

using namespace std;

class Example
{
public:
    typedef map<FeatureID,double> FeatureMap;

    Example();

    bool Insert( FeatureID id, double strgth = 1.0 );
    void Erase();

    // Feature access
    bool HasFeature( FeatureID id );
    FeatureMap::const_iterator GetFeatureBegin();
    FeatureMap::const_iterator GetFeatureEnd();

    // Information and debugging support (Output to the terminal)
    void Show();

    bool Parse( string& in );

    // Example persistence
    bool Read( ifstream& in );
    bool ReadLabeled( ifstream& in );
    void Write( ofstream& out );

    FeatureID label;
    FeatureMap features;
};

inline Example::Example() :
      label((FeatureID)-1)
{}

inline bool Example::Insert( FeatureID id, double strgth )
{
    return features.insert(make_pair(id,strgth)).second;
}

inline void Example::Erase()
{
    if (!features.empty())
    {
        features.clear();
    }
}

inline bool Example::HasFeature( FeatureID id )
{
    return (features.find(id) != features.end());
}

inline Example::FeatureMap::const_iterator Example::GetFeatureBegin()
{
    return features.begin();
}

inline Example::FeatureMap::const_iterator Example::GetFeatureEnd()
{
    return features.end();
}

#endif

